"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var node_fetch_1 = require("node-fetch");
var form_data_1 = require("form-data");
var ElasticAPMSourceMapPlugin = /** @class */ (function () {
    function ElasticAPMSourceMapPlugin(config) {
        this.config = config;
    }
    ElasticAPMSourceMapPlugin.prototype.apply = function (compiler) {
        var _this = this;
        compiler.hooks.afterEmit.tapPromise('ElasticAPMSourceMapPlugin', function (compilation) {
            var chunks = compilation.getStats().toJson().chunks;
            return R.compose(function (promises) { return Promise.all(promises); }, R.map(function (_a) {
                var sourceFile = _a.sourceFile, sourceMap = _a.sourceMap;
                var formData = new form_data_1.default();
                formData.append('sourcemap', compilation.assets[sourceMap].source());
                formData.append('service_version', _this.config.serviceVersion);
                formData.append('bundle_filepath', _this.config.publicPath + "/" + sourceFile);
                formData.append('service_name', _this.config.serviceName);
                var headers = _this.config.secret
                    ? { Authorization: "Bearer " + _this.config.secret }
                    : undefined;
                return node_fetch_1.default(_this.config.serverURL, {
                    method: 'POST',
                    body: formData,
                    headers: headers
                })
                    .then(function (response) {
                    if (response.ok)
                        return response.json();
                    else {
                        throw new Error("Error while uploading " + sourceMap + " to Elastic APM");
                    }
                })
                    .then(function () {
                    console.info("Uploaded " + sourceMap + " to Elastic APM"); // eslint-disable-line no-console
                });
            }), R.map(function (_a) {
                var files = _a.files;
                var sourceFile = R.find(R.test(/\.js$/), files);
                var sourceMap = R.find(R.test(/\.js\.map$/), files);
                return { sourceFile: sourceFile, sourceMap: sourceMap };
            }))(chunks);
        });
    };
    return ElasticAPMSourceMapPlugin;
}());
exports.default = ElasticAPMSourceMapPlugin;
//# sourceMappingURL=elastic-apm-sourcemap-webpack-plugin.js.map